==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/Semaphores.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.ext;
namespace com.db4o.test {

   public class Semaphores : AllTestsConfAll {
      
      public Semaphores() : base() {
      }
      
      public void test() {
         ExtObjectContainer eoc1 = Tester.objectContainer();
         eoc1.setSemaphore("SEM", 0);
         Tester.ensure(eoc1.setSemaphore("SEM", 0) == true);
         if (Tester.clientServer) {
            ExtObjectContainer client21 = null;
            try {
               {
                  client21 = Db4o.openClient(SERVER_HOSTNAME, SERVER_PORT, DB4O_USER, DB4O_PASSWORD).ext();
                  Tester.ensure(client21.setSemaphore("SEM", 0) == false);
                  eoc1.releaseSemaphore("SEM");
                  Tester.ensure(client21.setSemaphore("SEM", 0) == true);
               }
            }  catch (Exception e) {
               {
                  j4o.lang.JavaSystem.printStackTrace(e);
                  return;
               }
            }
         } else {
            eoc1.releaseSemaphore("SEM");
         }
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/Semaphores.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.ext;
namespace com.db4o.test {

   public class Semaphores : AllTestsConfAll {
      
      public Semaphores() : base() {
      }
      
      public void Test() {
         ExtObjectContainer eoc1 = Tester.ObjectContainer();
         eoc1.SetSemaphore("SEM", 0);
         Tester.Ensure(eoc1.SetSemaphore("SEM", 0) == true);
         if (Tester.clientServer) {
            ExtObjectContainer client21 = null;
            try {
               {
                  client21 = Db4o.OpenClient(SERVER_HOSTNAME, SERVER_PORT, DB4O_USER, DB4O_PASSWORD).Ext();
                  Tester.Ensure(client21.SetSemaphore("SEM", 0) == false);
                  eoc1.ReleaseSemaphore("SEM");
                  Tester.Ensure(client21.SetSemaphore("SEM", 0) == true);
               }
            }  catch (Exception e) {
               {
                  j4o.lang.JavaSystem.PrintStackTrace(e);
                  return;
               }
            }
         } else {
            eoc1.ReleaseSemaphore("SEM");
         }
      }
   }
}
